FaultInjector

Trait FaultInjector 

pub trait FaultInjector: Send + Sync {
    // Required method
    fn should_fail(&self, point: FaultPoint) -> bool;
}
Test seam for simulating process loss at durable boundaries.

Required Methods

fn should_fail(&self, point: FaultPoint) -> bool

Return true to stop at point and leave normal recovery artifacts.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors